/*
  Java gfx-test framework

   Copyright (C) 2010, 2011  Red Hat

This file is part of IcedTea.

IcedTea is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2, or (at your option)
any later version.

IcedTea is distributed in the hope that it will be useful, but
WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
General Public License for more details.

You should have received a copy of the GNU General Public License
along with IcedTea; see the file COPYING.  If not, write to the
Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
02110-1301 USA.

Linking this library statically or dynamically with other modules is
making a combined work based on this library.  Thus, the terms and
conditions of the GNU General Public License cover the whole
combination.

As a special exception, the copyright holders of this library give you
permission to link this library with independent modules to produce an
executable, regardless of the license terms of these independent
modules, and to copy and distribute the resulting executable under
terms of your choice, provided that you also meet, for each linked
independent module, the terms and conditions of the license of that
module.  An independent module is a module which is not derived from
or based on this library.  If you modify this library, you may extend
this exception to your version of the library, but you are not
obligated to do so.  If you do not wish to do so, delete this
exception statement from your version.
*/

package org.gfxtest.testsuites;

import java.awt.*;
import java.io.IOException;

import org.gfxtest.framework.*;
import org.gfxtest.framework.annotations.*;

/**
* This test renders various empty "3d" rectangles using identity transformation matrix.
*
* @author Pavel Tisnovsky
*/
@TestType(TestTypes.RENDER_TEST)
@GraphicsPrimitive(GraphicsPrimitives.THREE_D_RECTANGLE)
@RenderStyle(RenderStyles.NORMAL)
@Transformation(Transformations.NONE)
@Zoom(1)
public class Normal3DRectangles extends GfxTest
{

    private void draw3DRect(TestImage image, Graphics2D graphics, float width, boolean raised)
    {
        graphics.setStroke(new BasicStroke(width,              // width
                                     BasicStroke.JOIN_MITER,   // cap
                                     BasicStroke.JOIN_BEVEL)); // join
        int xc = image.getCenterX();
        int yc = image.getCenterY();
        double rmaj = (xc > yc ? yc : xc) - (MAJOR_RADIUS - MINOR_RADIUS);

        for (float m = 1.0f; m >= 0.0f; m -= 1.0 / 16.0)
        {
            Color color = new Color(Color.HSBtoRGB(m, 1.0f, 1.0f));
            graphics.setColor(color);
            double angle = Math.PI * 2 * m;
            int x = (int) (xc + rmaj * Math.cos(angle));
            int y = (int) (yc + rmaj * Math.sin(angle));
            int radius = (int)(MINOR_RADIUS + m * (MAJOR_RADIUS - MINOR_RADIUS));
            graphics.draw3DRect(x - radius, y - radius, radius << 1, radius << 1, raised);
        }
        drawCross(graphics, xc, yc, CROSS_SIZE);
    }

    @Override
    protected void runOtherTests(GfxTestConfiguration configuration)
    {
        float[] widths = { 1.0f, 2.0f, 5.0f, 10.0f, 20.0f, 40.0f };
        int testNumber = 0;
        for (float width : widths)
        {
            for (boolean raised : new boolean[]{false, true})
            {
                String testName = "test" + testNumber + raised; //$NON-NLS-1$
                this.log.logBegin(testName);
                TestImage image = new TestImage(configuration, 1);
                Graphics2D graphics = image.getGraphics();
                draw3DRect(image, graphics, width, raised);
                graphics.dispose();
                try
                {
                    image.writeImage(configuration, this.suiteName, testName);
                }
                catch (IOException e)
                {
                    e.printStackTrace();
                }
                this.log.logEnd(testName);
                testNumber++;
            }
        }
    }

    public static void main(String[] args)
    {
        new Normal3DRectangles().runTestSuite(args);
    }

}
